
.. If you created a package, create one automodule per module in the package.

.. If your library file(s) are nested in a directory (e.g. /adafruit_foo/foo.py)
.. use this format as the module name: "adafruit_foo.foo"

API Reference
#############

.. automodule:: adafruit_bitmap_font
   :members:

.. automodule:: adafruit_bitmap_font.bdf
  :members:

.. automodule:: adafruit_bitmap_font.bitmap_font
 :members:

.. automodule:: adafruit_bitmap_font.glyph_cache
 :members:

.. automodule:: adafruit_bitmap_font.pcf
 :members:

.. automodule:: adafruit_bitmap_font.ttf
 :members:
